From d8ffcee1b733d9b5b5c9f093002deb25c4c82472 Mon Sep 17 00:00:00 2001
From: Guo Xinle <guoxinle1@huawei.com>
Date: Sat, 20 Feb 2021 16:37:25 +0800
Subject: [PATCH] Block: replace testcases backing file from `/tmp` to TempFile

It will failed if there is no `/tmp/` path in the runtime.
So, use TempFile as an backing file.

Signed-off-by: Guo Xinle <guoxinle1@huawei.com>
---
 device_model/src/virtio/block.rs | 13 +++++++------
 1 file changed, 7 insertions(+), 6 deletions(-)

diff --git a/device_model/src/virtio/block.rs b/device_model/src/virtio/block.rs
index 913afd3..0491409 100644
--- a/device_model/src/virtio/block.rs
+++ b/device_model/src/virtio/block.rs
@@ -931,6 +931,7 @@ mod tests {
     use machine_manager::config::IothreadConfig;
     use std::sync::Once;
     use std::{thread, time::Duration};
+    use vmm_sys_util::tempfile::TempFile;
 
     const VIRTQ_DESC_F_NEXT: u16 = 0x01;
     const VIRTQ_DESC_F_WRITE: u16 = 0x02;
@@ -1044,16 +1045,16 @@ mod tests {
         assert!(block.interrupt_cb.is_none());
         assert!(block.sender.is_none());
 
-        // Realize block device
+        // Realize block device: create TempFile as backing file.
         block.blk_cfg.read_only = true;
         block.blk_cfg.direct = false;
-        block.blk_cfg.path_on_host = "/tmp/".to_string();
-        // Realize will failed, because path_on_host is not a disk image path.
-        assert!(block.realize().is_err());
+        let f = TempFile::new().unwrap();
+        block.blk_cfg.path_on_host = f.as_path().to_str().unwrap().to_string();
+        assert!(block.realize().is_ok());
 
         block.blk_cfg.direct = true;
-        block.blk_cfg.path_on_host = "".to_string();
-        assert_eq!(block.realize().is_ok(), true);
+        // Realize will failed if we create TempFile as backing file and set `O_DIRECT`.
+        assert!(block.realize().is_err());
         assert_eq!(block.device_type(), VIRTIO_TYPE_BLOCK);
         assert_eq!(block.queue_num(), QUEUE_NUM_BLK);
         assert_eq!(block.queue_size(), QUEUE_SIZE_BLK);
-- 
2.27.0.windows.1

